==> aws-java-sdk-cloudformation-1.10.11-sources.jar: com/amazonaws/services/cloudformation/model/transform/GetStackPolicyResultStaxUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cloudformation.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.cloudformation.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * Get Stack Policy Result StAX Unmarshaller
 */
public class GetStackPolicyResultStaxUnmarshaller implements Unmarshaller<GetStackPolicyResult, StaxUnmarshallerContext> {

    public GetStackPolicyResult unmarshall(StaxUnmarshallerContext context) throws Exception {
        GetStackPolicyResult getStackPolicyResult = new GetStackPolicyResult();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument()) targetDepth += 2;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument()) return getStackPolicyResult;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {
                if (context.testExpression("StackPolicyBody", targetDepth)) {
                    getStackPolicyResult.setStackPolicyBody(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return getStackPolicyResult;
                }
            }
        }
    }

    private static GetStackPolicyResultStaxUnmarshaller instance;
    public static GetStackPolicyResultStaxUnmarshaller getInstance() {
        if (instance == null) instance = new GetStackPolicyResultStaxUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-cloudformation-1.10.31-sources.jar: com/amazonaws/services/cloudformation/model/transform/GetStackPolicyResultStaxUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cloudformation.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.cloudformation.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * GetStackPolicyResult StAX Unmarshaller
 */
public class GetStackPolicyResultStaxUnmarshaller implements
        Unmarshaller<GetStackPolicyResult, StaxUnmarshallerContext> {

    public GetStackPolicyResult unmarshall(StaxUnmarshallerContext context)
            throws Exception {
        GetStackPolicyResult getStackPolicyResult = new GetStackPolicyResult();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument())
            targetDepth += 2;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument())
                return getStackPolicyResult;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {

                if (context.testExpression("StackPolicyBody", targetDepth)) {
                    getStackPolicyResult
                            .setStackPolicyBody(StringStaxUnmarshaller
                                    .getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return getStackPolicyResult;
                }
            }
        }
    }

    private static GetStackPolicyResultStaxUnmarshaller instance;

    public static GetStackPolicyResultStaxUnmarshaller getInstance() {
        if (instance == null)
            instance = new GetStackPolicyResultStaxUnmarshaller();
        return instance;
    }
}
